@@ -89,6 +89,7 @@ def registerStatusLinks(version: int) -> Dict[str, Union[bool, str, List[Dict[st
             cache_id = cache.add_cache_entry("/v" + str(version) + "/main_memory/status/" + datatype)
             if duration >0:
                 cache.addParameter(cache_id, "duration", str(duration))
+                cache.commit()
             
             data = memory.plugin.getStatusData(dataType = datatype,
                                                duration = duration,
@@ -97,6 +98,7 @@ def registerStatusLinks(version: int) -> Dict[str, Union[bool, str, List[Dict[st
                 for data_element in data:
                     for result_name, result in data_element.items():
                         cache.addResult(cache_id, result_name, result)
+                cache.commit()
                 return make_response(jsonify(data), 200)
             
             logging.warning("Accessed /v%i/main_memory/status/%s, but not avaiable", version, datatype)
@@ -119,7 +121,7 @@ def registerConfigLinks(version: int) -> Dict[str, Union[bool, str, List[Dict[st
     if pluginInformation.memory_is_working:
         for i, typeStr in enumerate(types):
             config_links.append({
-            "link": "/v" + str(version) + main_memory_path + "/status/" + typeStr,
+            "link": "/v" + str(version) + main_memory_path + "/config/" + typeStr,
             "isOptional": True,
             "description": descriptions[i],
             "parameters": [
