@@ -9,7 +9,7 @@ from JuMonC.handlers.base import api_version_path, check_version, RESTAPI
 from JuMonC.models import pluginInformation
 from JuMonC.authentication import scopes
 from JuMonC.authentication.check import check_auth
-from JuMonC.tasks import LinuxNetwork
+from JuMonC.tasks import LinuxNetwork, taskPool
 from JuMonC import settings
 
 import JuMonC.models.cache.helper as cache
@@ -89,18 +89,15 @@ def registerStatusLinks(version: int) -> Dict[str, Union[bool, str, List[Dict[st
                 if duration > 0:
                     cache.addParameter(cache_id, "duration", str(duration))
                 cache.addParameter(cache_id, "interface", interface)
-                data = LinuxNetwork.plugin.getData(dataType = datatype,
-                                                        duration = duration,
-                                                        interface = interface,
-                                                        overrideHumanReadableWithValue = humanReadable)
-                for data_element in data:
-                    for result_part_name, part in data_element.items():
-                        if result_part_name == "interface":
-                            continue
-                        if isinstance(part, dict):
-                            for result_name, result in part.items():
-                                cache.addResult(cache_id, result_part_name + result_name, result)
+                cache.commit()
                 
+                data = networkStatusTask(cache_id = cache_id,
+                                         duration = duration,
+                                         datatype = datatype,
+                                         interface = interface,
+                                         humanReadable = humanReadable)
+                if data is None:
+                    return make_response(jsonify({"link": "/v" + str(version) + "/cache/id/?id=" + str(cache_id)}), 200)
                 return make_response(jsonify(data, 200))
             abort(404)
             return make_response("",404)
@@ -114,3 +111,25 @@ def registerStatusLinks(version: int) -> Dict[str, Union[bool, str, List[Dict[st
              "description": "Supply a token that shows you are allowed to access this link (or login once using /login)"}
         ]
     }
+
+
+@taskPool.executeAsTask
+def networkStatusTask(cache_id: int, duration: float, datatype: str, interface: str, humanReadable:bool
+                     ) -> List[Dict[str, Union[str, Dict[str, Union[int, float, str]]]]]:
+    data = LinuxNetwork.plugin.getData(dataType = datatype,
+                                            duration = duration,
+                                            interface = interface,
+                                            overrideHumanReadableWithValue = humanReadable)
+    for data_element in data:
+        interface_str:Union[str, Dict[str, Union[int, float, str]]] = data_element["interface"]
+        if not isinstance(interface_str, str):
+            logging.warning("Unexpected datatype in passing networkdata into cache")
+            continue
+        for result_part_name, part in data_element.items():
+            if result_part_name == "interface":
+                continue
+            if isinstance(part, dict):
+                for result_name, result in part.items():
+                    cache.addResult(cache_id, interface_str + "_" + result_part_name + "_" + result_name, result)
+    cache.commit()
+    return data
\ No newline at end of file
