@@ -11,15 +11,16 @@ from typing import Any
 
 
 from JuMonC import settings
-from JuMonC._version import __version__
+from JuMonC._version import __version__, __REST_version__, __DB_version__
 from JuMonC.helpers.startup import communicateAvaiablePlugins
 from JuMonC.helpers.cmdArguments import parseCMDOptions
-from JuMonC.models.plugins import gatherRESTpaths, startPlugins, registerRESTpaths
+from JuMonC.helpers.PluginManager import addAllPathsAsPlugins, initPluginsREST, logAllPlugins
+from JuMonC.authentication.tokens import registerTokens
+from JuMonC.handlers.base import setRESTVersion
 
 
 
 logger = logging.getLogger(__name__)
-logging.info("Running JuMonC with version: %s", __version__)
 
 mpi4py.rc.threads = True
 mpi4py.rc.thread_level = "funneled"
@@ -29,8 +30,17 @@ rank = comm.Get_rank()
 
 def startJuMonC() -> None:
     parseCMDOptions(sys.argv[1:])
-    startPlugins()
+    
+    logging.info("Running JuMonC with version: %s", __version__)
+    logging.debug("Running JuMonC with REST-API version: %s", __REST_version__)
+    logging.debug("Running JuMonC with DB version: %s", __DB_version__)
+    
+    logAllPlugins()
+    
     communicateAvaiablePlugins()
+    addAllPathsAsPlugins()
+    
+    registerTokens()
 
     #pylint: disable=import-outside-toplevel
     if rank == 0:
@@ -39,11 +49,10 @@ def startJuMonC() -> None:
     
         from JuMonC.tasks import mpiroot
         from JuMonC.models.cache.database import Base, engine, db_session
-        
-        gatherRESTpaths()
-    
+
+        setRESTVersion()
         main.registerRestApiPaths()
-        registerRESTpaths()
+        initPluginsREST()
 
         if settings.SSL_ENABLED:
             JuMonC_SSL = settings.SSL_MODE
